# Flare Utilities

Flare Utilities having support libraries for `Flare-BDD` framework for reporting purposes.

### What is included with Flare Utilities?

- 🎨 Flare has its own in-build HTML report which supports `behave` framework
- 📝 Auto generates folders for every test run which contains `logs`, `HTML report` and `supporting CSS file`

### Flare - Reporting Capabilities

- 🖼️ Having a minimalistic reporting mechanism which displays test cases in accordians (which can be expanded and collapsed)
- 🏷️ Each testcases will have test case summary and test step summaries
- ✔️ For all successful test steps, carries a PASSED icon
- ❌ For all unsuccessful test steps, carries a FAILED icon
- 🐞 For any exception thrown by system at runtime, carries a BUG icon along with entire test run will be terminated
- Each test case accordian displays overall status highlighted in `GREEN` or `RED`
- For instance if any one test case gets FAILED, overall test case will be shown in `RED`
- PASS and FAIL: [Flare - Test Summary Report - 1](Reporting/Sample_TC_PASS/Flare%20-%20Test%20Summary%20Report.html)
- BUG/EXCEPTION: [Flare - Test Summary Report - 2](Reporting/Sample_TC_BUG/Flare%20-%20Test%20Summary%20Report.html)

---

## Install the project

- To include `Flare_Utilities` to the `Flare-BDD` project, just like any other pip installables,

```bash
$ pip install Flare_Utilities
```
